==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTINVOICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERCONTRACTINVOICEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTINVOICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTINVOICECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTINVOICEREVISION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTINVOICEID_Type", propOrder = {
    "customercontractinvoicecode",
    "description",
    "organizationid",
    "customercontractinvoicerevision"
})
public class CUSTOMERCONTRACTINVOICEID_Type {

    @XmlElement(name = "CUSTOMERCONTRACTINVOICECODE", required = true)
    protected String customercontractinvoicecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CUSTOMERCONTRACTINVOICEREVISION")
    protected long customercontractinvoicerevision;

    /**
     * Gets the value of the customercontractinvoicecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERCONTRACTINVOICECODE() {
        return customercontractinvoicecode;
    }

    /**
     * Sets the value of the customercontractinvoicecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERCONTRACTINVOICECODE(String value) {
        this.customercontractinvoicecode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the customercontractinvoicerevision property.
     * 
     */
    public long getCUSTOMERCONTRACTINVOICEREVISION() {
        return customercontractinvoicerevision;
    }

    /**
     * Sets the value of the customercontractinvoicerevision property.
     * 
     */
    public void setCUSTOMERCONTRACTINVOICEREVISION(long value) {
        this.customercontractinvoicerevision = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTINVOICEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERCONTRACTINVOICEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTINVOICEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTINVOICECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERCONTRACTINVOICEREVISION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTINVOICEID_Type", propOrder = {
    "customercontractinvoicecode",
    "description",
    "organizationid",
    "customercontractinvoicerevision"
})
public class CUSTOMERCONTRACTINVOICEID_Type {

    @XmlElement(name = "CUSTOMERCONTRACTINVOICECODE", required = true)
    protected String customercontractinvoicecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "CUSTOMERCONTRACTINVOICEREVISION")
    protected long customercontractinvoicerevision;

    /**
     * Obtient la valeur de la propriété customercontractinvoicecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMERCONTRACTINVOICECODE() {
        return customercontractinvoicecode;
    }

    /**
     * Définit la valeur de la propriété customercontractinvoicecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMERCONTRACTINVOICECODE(String value) {
        this.customercontractinvoicecode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété customercontractinvoicerevision.
     * 
     */
    public long getCUSTOMERCONTRACTINVOICEREVISION() {
        return customercontractinvoicerevision;
    }

    /**
     * Définit la valeur de la propriété customercontractinvoicerevision.
     * 
     */
    public void setCUSTOMERCONTRACTINVOICEREVISION(long value) {
        this.customercontractinvoicerevision = value;
    }

}
